qustop.OptDist
==============

.. currentmodule:: qustop

.. autoclass:: OptDist

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~OptDist.__init__
      ~OptDist.convert_measurements
      ~OptDist.solve
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~OptDist.measurements
      ~OptDist.value
   
   